# -*- mode: rpm-spec ; mode: font-lock -*-

Summary: Library providing specific CCP4 functionality 
Name: gpp4
Version: 1.3.1
Release: 2%{?dist}
License: LGPLv2
Group: System Environment/Libraries
URL: https://launchpad.net/gpp4
Source0: http://launchpad.net/gpp4/1.3/%{version}/+download/%{name}-%{version}.tar.gz
BuildRequires: doxygen
BuildRequires: mmdb-devel
BuildRequires: gcc-gfortran

%description

The CCP4 software suite is based around a library of routines which
cover common tasks, such as file opening, parsing keyworded input,
reading and writing of standard data formats, applying symmetry
operations, etc. Programs in the suite call these routines which, as
well as saving the programmer some effort, ensure that the varied
programs in the suite have a similar look-and-feel.

The library contains several subcomponents: 
  * CMTZ library -- Contains a variety of functions for manipulating 
    the data structure, for example adding crystals, datasets or columns. 
    The data structure can be dumped to an output MTZ data file.
  * CMAP library -- Functions defining the C-level API for accessing 
    CCP4 map files.
  * CSYM library -- a collection of functions centred around a data file 
    syminfo.lib which is auto-generated from sgtbx (the Space Group Toolbox 
    of cctbx).
  * CCP4 utility library -- many utility functions which either give 
    specific CCP4 or platform independent functionality.
  * CCP4 Parser library -- provides CCP4-style parsing, as used for 
    processing keywords of CCP4 programs, MTZ header records, etc.
  * CCP4 resizable arrays -- defines an object and methods which looks 
    just like a simple C array, but can be resized at will without 
    incurring excessive overheads.

This package contains the shared library components needed for programs
that have been compiled with the gpp4 library. 

%package devel
Summary: Header files and library for developing free CCP4 programs
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig
Group: Development/Libraries

%description devel
The CCP4 software suite is based around a library of routines which
cover common tasks, such as file opening, parsing keyworded input,
reading and writing of standard data formats, applying symmetry
operations, etc. Programs in the suite call these routines which, as
well as saving the programmer some effort, ensure that the varied
programs in the suite have a similar look-and-feel.

This package contains libraries and header files needed for program
development.

%prep
%setup -q

%build
%configure --disable-static
# die rpath, die.
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
make %{?_smp_mflags}
doxygen

%install
rm -rf %{buildroot}
make install DESTDIR=$RPM_BUILD_ROOT INSTALL='install -p'

# remove unpackaged files from the buildroot
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc README COPYING NEWS AUTHORS
%{_datadir}/gpp4/
%{_libdir}/libgpp4.so.0
%{_libdir}/libgpp4.so.0.0.0
%{_libdir}/libgpp4f.so.0
%{_libdir}/libgpp4f.so.0.0.0

%files devel
%defattr(-,root,root,-)
%doc doc/html
%{_includedir}/gpp4
%{_libdir}/libgpp4.so
%{_libdir}/libgpp4f.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}f.pc

%changelog
* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Feb 25 2011 Tim Fenn <fenn@stanford.edu> - 1.3.1-1
- update to 1.3.1 stable
- remove s390 patch (merged upstream)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 15 2010 Dan Horák <dan[at]danny.cz> - 1.2.1-2
- fix build on s390(x)

* Mon Apr 26 2010 Tim Fenn <fenn@stanford.edu> - 1.2.1-1
- update to stable branch (1.2.1)
- patches, autotool rebuild unecessary
- fix URL

* Wed Sep 16 2009 Tim Fenn <fenn@stanford.edu> - 1.2.0-2.20090916bzr58
- add patch for mixed fortran/c library
- add gfortran to buildrequires
- updated PPC patches

* Wed Sep 16 2009 Tim Fenn <fenn@stanford.edu> - 1.2.0-1.20090916bzr58
- update to 1.2.0
- update to new website
- include libgpp4f
- add MMDB buildreq

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jun 04 2009 Tim Fenn <fenn@stanford.edu> - 1.1.0-3
- add ARM patch to ccp4_sysdep (Jitesh Shah)

* Tue May 19 2009 Tim Fenn <fenn@stanford.edu> - 1.1.0-2
- patch ccp4_sysdep.h for ppc

* Tue May 19 2009 Tim Fenn <fenn@stanford.edu> - 1.1.0-1
- update to 1.1.0

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Dec 21 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-13
- remove latex files from doc, just include html (477392)

* Sat Dec 20 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-12
- add libtoolize

* Tue Oct 28 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-11
- fix buildrequires

* Mon Oct 27 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-10
- add math lib to linker
- fix duplicate docs
- minor edit to make install

* Sat Oct 25 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-9
- change name libgpp4 to gpp4
- add smp make macro
- add PPC patch

* Mon Jun  9 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-8
- remove test from -devel

* Thu May 29 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-7
- minor spec changes

* Wed May 28 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-6
- fix ldconfig, requires, buildroot, naming scheme

* Tue May 27 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-5
- remove static libs

* Mon May 26 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-4
- spec cleanup

* Tue Feb 26 2008 Tim Fenn <fenn@stanford.edu> - 1.0.4-3
- Update using fedora packaging recommendations

* Sun Sep 02 2007 Morten Kjeldgaard <mok@bioxray.dk> - 1.0.4-2
- Initial build. 

####
